summaryrefslogtreecommitdiff
path: root/plugins/dfxvideo
diff options
context:
space:
mode:
authorSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
committerSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
commit5f868fa161d5827e45a060a0b17b44a997625315 (patch)
tree1694ae3dfcb0189abdf098edbf6dae0bf2a18e4d /plugins/dfxvideo
parentc7eb23ccf1813fb4ca47c309c40baff308151237 (diff)
downloadpcsxr-5f868fa161d5827e45a060a0b17b44a997625315.tar.gz
Rebranding.
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@67621 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'plugins/dfxvideo')
-rw-r--r--plugins/dfxvideo/Makefile.am4
-rw-r--r--plugins/dfxvideo/cfg.c6
-rw-r--r--plugins/dfxvideo/gpu.c8
-rw-r--r--plugins/dfxvideo/gpucfg-0.1df/main.c4
4 files changed, 11 insertions, 11 deletions
diff --git a/plugins/dfxvideo/Makefile.am b/plugins/dfxvideo/Makefile.am
index a7515a21..7e56a9c6 100644
--- a/plugins/dfxvideo/Makefile.am
+++ b/plugins/dfxvideo/Makefile.am
@@ -17,9 +17,9 @@ libdir = @libdir@/games/psemu/
lib_LTLIBRARIES = libDFXVideo.la
-libDFXVideo_la_SOURCES = gpu.c cfg.c draw.c fps.c key.c menu.c prim.c soft.c zn.c
+libDFXVideo_la_SOURCES = gpu.c gpu.h cfg.c cfg.h draw.c draw.h fps.c fps.h key.c key.h menu.c menu.h prim.c prim.h soft.c soft.h zn.c swap.h externals.h hq2x.h hq3x.h interp.h
if X86_NASM
-libDFXVideo_la_SOURCES += i386.asm
+libDFXVideo_la_SOURCES += i386.asm macros.inc
AM_CPPFLAGS += -DUSE_NASM=1
endif
libDFXVideo_la_LDFLAGS = -module -avoid-version
diff --git a/plugins/dfxvideo/cfg.c b/plugins/dfxvideo/cfg.c
index 70c08461..09d0485c 100644
--- a/plugins/dfxvideo/cfg.c
+++ b/plugins/dfxvideo/cfg.c
@@ -96,7 +96,7 @@ void ReadConfigFile()
{
strcpy(t,"cfg/dfxvideo.cfg");
in = fopen(t,"rb");
- if(!in) sprintf(t,"%s/.pcsx/plugins/dfxvideo.cfg",getenv("HOME"));
+ if(!in) sprintf(t,"%s/.pcsxr/plugins/dfxvideo.cfg",getenv("HOME"));
else fclose(in);
}
else fclose(in);
@@ -188,7 +188,7 @@ void ExecCfg(char *arg) {
return;
}
- sprintf(cfg, "%s/.pcsx/plugins/cfg/cfgDFXVideo", getenv("HOME"));
+ sprintf(cfg, "%s/.pcsxr/plugins/cfg/cfgDFXVideo", getenv("HOME"));
if (stat(cfg, &buf) != -1) {
if (fork() == 0) {
execl(cfg, "cfgDFXVideo", arg, NULL);
@@ -256,7 +256,7 @@ void WriteConfig(void) {
{
strcpy(t,"cfg/dfxvideo.cfg");
out = fopen(t,"rb");
- if(!out) sprintf(t,"%s/.pcsx/plugins/dfxvideo.cfg",getenv("HOME"));
+ if(!out) sprintf(t,"%s/.pcsxr/plugins/dfxvideo.cfg",getenv("HOME"));
else fclose(out);
}
else fclose(out);
diff --git a/plugins/dfxvideo/gpu.c b/plugins/dfxvideo/gpu.c
index bd14f28f..ef06be1a 100644
--- a/plugins/dfxvideo/gpu.c
+++ b/plugins/dfxvideo/gpu.c
@@ -294,9 +294,9 @@ static void DoTextSnapShot(int iNum)
char *pB;
#ifdef _WINDOWS
- sprintf(szTxt,"snap\\pcsx%04d.txt",iNum);
+ sprintf(szTxt,"snap\\pcsxr%04d.txt",iNum);
#else
- sprintf(szTxt,"%s/pcsx%04d.txt",getenv("HOME"),iNum);
+ sprintf(szTxt,"%s/pcsxr%04d.txt",getenv("HOME"),iNum);
#endif
if ((txtfile = fopen(szTxt, "wb")) == NULL)
@@ -356,9 +356,9 @@ void CALLBACK GPUmakeSnapshot(void)
{
snapshotnr++;
#ifdef _WINDOWS
- sprintf(filename,"snap\\pcsx%04ld.bmp",snapshotnr);
+ sprintf(filename,"snap\\pcsxr%04ld.bmp",snapshotnr);
#else
- sprintf(filename, "%s/pcsx%04ld.bmp", getenv("HOME"), snapshotnr);
+ sprintf(filename, "%s/pcsxr%04ld.bmp", getenv("HOME"), snapshotnr);
#endif
bmpfile = fopen(filename,"rb");
diff --git a/plugins/dfxvideo/gpucfg-0.1df/main.c b/plugins/dfxvideo/gpucfg-0.1df/main.c
index 07d362e3..4edc0a25 100644
--- a/plugins/dfxvideo/gpucfg-0.1df/main.c
+++ b/plugins/dfxvideo/gpucfg-0.1df/main.c
@@ -144,7 +144,7 @@ main (int argc, char *argv[])
if (strcmp(argv[1], "ABOUT") == 0) {
const char *authors[]= {"Pete Bernert and the P.E.Op.S. team", "Ryan Schultz", "Andrew Burton", NULL};
widget = gtk_about_dialog_new ();
- gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (widget), "P.E.Op.S PCSX Video Plugin");
+ gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (widget), "P.E.Op.S PCSXR Video Plugin");
gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (widget), "1.17");
gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (widget), authors);
gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (widget), "http://pcsx-df.sourceforge.net/");
@@ -178,7 +178,7 @@ main (int argc, char *argv[])
fclose(in);
}
else{ pB=0;printf("Couldn't find config file %s\n", cfg);}
/* ADB TODO Parse this like we parse the config file in PCSX - use common functions! */
val=1;
if(pB)
{
@@ -178,7 +178,7 @@ main (int argc, char *argv[])
}
else{ pB=0;printf("Couldn't find config file %s\n", cfg);}
-/* ADB TODO Parse this like we parse the config file in PCSX - use common functions! */
+/* ADB TODO Parse this like we parse the config file in PCSXR - use common functions! */
val=1;
if(pB)